{% for page_item in page_obj %}
    {% if forloop.last and next_page_url %}
        <div hx-get="{{next_page_url}}" hx-trigger="revealed" hx-swap="afterend"></div>
    {% endif %}
    {% include template_for_item with entry=page_item %}
{% endfor %}
